Welcome | CWI

# Welcome

Centrum Wiskunde & Informatica (CWI) is the national research institute for mathematics and computer science in the Netherlands. The institute's strategy for the period up to 2012 is to concentrate research on four broad, societally relevant themes:

- nl

05-09-08

### Best Paper Award for Interactive Television Research

read more

### New website

read more

### New (temporary) entrance library

read more

### Smalltalk conference at CWI

read more

### SIGMA prize 2008 for DisWis

read more

### Luque and Ebert publish on connections in lightning

read more